Module: Mathtype3
- Defined in:
- lib/mathtype-0.0.7.5/lib/records3/pile.rb,
lib/mathtype-0.0.7.5/lib/records3/end.rb,
lib/mathtype-0.0.7.5/lib/records3/char.rb,
lib/mathtype-0.0.7.5/lib/records3/font.rb,
lib/mathtype-0.0.7.5/lib/records3/line.rb,
lib/mathtype-0.0.7.5/lib/records3/mtef.rb,
lib/mathtype-0.0.7.5/lib/records3/size.rb,
lib/mathtype-0.0.7.5/lib/records3/tmpl.rb,
lib/mathtype-0.0.7.5/lib/records3/nudge.rb,
lib/mathtype-0.0.7.5/lib/records3/ruler.rb,
lib/mathtype-0.0.7.5/lib/records3/embell.rb,
lib/mathtype-0.0.7.5/lib/records3/matrix.rb,
lib/mathtype-0.0.7.5/lib/records3/options.rb,
lib/mathtype-0.0.7.5/lib/records3/snapshot.rb,
lib/mathtype-0.0.7.5/lib/records3/typesizes.rb
Overview
Typesize records (10-14): Consists of: record type (10-14) These records are just short ways of specifying a simple typesize where dsize is zero. The tag value represents an lsize + 10. So if the tag value is 10, it means equation content following it will be Full size (szFULL), tag value 11 means szSUB, and so on. See typesize.
Defined Under Namespace
Modules: Snapshot Classes: Equation, NamedRecord, Nudge, Payload, RecordChar, RecordEmbell, RecordEnd, RecordFont, RecordFull, RecordLine, RecordMatrix, RecordNudge, RecordPile, RecordRuler, RecordSize, RecordSub, RecordSub2, RecordSubsym, RecordSym, RecordTmpl, mtef_options
Constant Summary collapse
- HALIGN =
Mathtype::HALIGN
- VALIGN =
Mathtype::VALIGN
- RECORD_NAMES =
{ 0 => "end", 1 => "slot", 2 => "char", 3 => "tmpl", 4 => "pile", 5 => "matrix", 6 => "embell", 7 => "ruler", 8 => "font", 9 => "size", 10 => "full", 11 => "sub", 12 => "sub2", 13 => "sym", 14 => "subsym", }
- OPTIONS =
{ # value => symbol # description # Option flag values for all equation structure records: "xfLMOVE" => 0x08, # nudge values follow tag # Option flag values for CHAR records: "xfLAUTO" => 0x01, # character is followed by an embellishment list "xfEMBELL" => 0x02, # character starts a function (sin, cos, etc.) # Option flag values for LINE records: "xfNULL" => 0x01, # line is a placeholder only (i.e. not displayed) "xfLSPACE" => 0x04, # line spacing value follows tag # Option flag values for LINE and PILE records: "xfRULER" => 0x02, # RULER record follows LINE or PILE record }